@@ -1,3 +1,4 @@
+pub mod alignment;
 pub mod corpus;
-pub mod ibm_model_1;
+pub mod model;
 pub mod vocabulary;
